==> worker_2.4.0.orig.tar.gz: worker-2.4.0/src/makedirop.h <==
/* makedirop.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: makedirop.h,v 1.3 2001/11/03 17:10:23 ralf Exp $ */

#ifndef MAKEDIROP_H
#define MAKEDIROP_H

#include "wdefines.h"
#include "functionproto.h"
//#include <aguix/awindow.h>
//#include <aguix/text.h>
//#include <aguix/solidbutton.h>
//#include <aguix/button.h>
//#include <aguix/cyclebutton.h>

class Worker;

class MakeDirOp:public FunctionProto
{
public:
  MakeDirOp(Worker*);
  virtual ~MakeDirOp();
  virtual MakeDirOp *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
  
  int normalmodemakedir();
};

#endif

==> worker_2.8.5.orig.tar.gz: worker-2.8.5/src/makedirop.h <==
/* makedirop.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: makedirop.h,v 1.6 2004/07/21 21:13:05 ralf Exp $ */

#ifndef MAKEDIROP_H
#define MAKEDIROP_H

#include "wdefines.h"
#include "functionproto.h"

class MakeDirOp:public FunctionProto
{
public:
  MakeDirOp();
  virtual ~MakeDirOp();
  MakeDirOp( const MakeDirOp &other );
  MakeDirOp &operator=( const MakeDirOp &other );

  virtual MakeDirOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
  
  int normalmodemakedir();
};

#endif
